What’s Next
===========

Congratulations on finishing the SymPy tutorial!

If you are a developer interested in using SymPy in your code, please visit
the :ref:`How-to Guides <guides>` which discuss key developer tasks.

Intermediate SymPy users and developers might want to visit the
:ref:`Explanations <explanations>` section for common pitfalls and advanced
topics.

The :ref:`SymPy API Reference <reference>` has a detailed description of the
SymPy API.

If you are interested in contributing to SymPy, visit the :ref:`contribution
guides <contributing>` and the full `Development Workflow
<https://github.com/sympy/sympy/wiki/Development-workflow>`_ guide on the
SymPy wiki.
